==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_admin.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_admin.php,v $
|     $Revision: 11461 $
|     $Date: 2010-04-05 17:34:57 -0400 (Mon, 05 Apr 2010) $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("ADLAN_0", "News");
define("ADLAN_1", "Add/edit/delete news items");
//define("ADLAN_2", "News Categories");
//define("ADLAN_3", "Add/edit/delete news categories");
define("ADLAN_4", "Preferences");
define("ADLAN_5", "Edit Site Preferences");
define("ADLAN_6", "Menus");
define("ADLAN_7", "Alter the order of your menus");
define("ADLAN_8", "Administrators");
define("ADLAN_9", "Add/delete site administrators");
define("ADLAN_10", "Admin password");
define("ADLAN_11", "Change your password");
//define("ADLAN_12", "Forums");
//define("ADLAN_13", "Add/Edit Forums");
//define("ADLAN_14", "Articles");
//define("ADLAN_15", "Add new/edit/delete articles");
//define("ADLAN_16", "Content");
//define("ADLAN_17", "Add new/edit/delete content pages");
//define("ADLAN_18", "Reviews");
//define("ADLAN_19", "Add new/edit/delete reviews");
//define("ADLAN_22", "Link Categories");
//define("ADLAN_23", "Add new/edit/delete link categories");
define("ADLAN_24", "Downloads");
define("ADLAN_25", "Manage Downloads");
//define("ADLAN_26", "Download Categories");
//define("ADLAN_27", "Add new/edit/delete download categories");
define("ADLAN_28", "Welcome Message");
define("ADLAN_29", "Set static welcome message");
define("ADLAN_30", "File Manager");
define("ADLAN_31", "Manage/upload files");
//define("ADLAN_32", "Submitted News");
//define("ADLAN_33", "Review user submitted news items");
define("ADLAN_34", "Banlist");
define("ADLAN_35", "Ban visitors");
define("ADLAN_36", "Users");
define("ADLAN_37", "Moderate site members");
define("ADLAN_38", "User Classes");
define("ADLAN_39", "Create/edit user classes");
define("ADLAN_40", "Maintenance");
define("ADLAN_41", "Take site down for maintenance");
define("ADLAN_42", "Custom Menus/Pages");
define("ADLAN_43", "Create custom menu items");
define("ADLAN_44", "Database");
define("ADLAN_45", "Database utilities");
define("ADLAN_46", "Logout");
define("ADLAN_47", "Welcome");
define("ADLAN_48", "Logged in");
define("ADLAN_49", "main site administrator");
//define("ADLAN_50", "permissions");
define("ADLAN_51", "Please log in to gain access to administration area");
define("ADLAN_52", "Admin Front Page");
define("ADLAN_53", "Leave Admin");
define("ADLAN_54", "Banners");
define("ADLAN_55", "Configure banners");
//define("ADLAN_56", "Chatbox");
//define("ADLAN_57", "Configure chatbox");
define("ADLAN_58", "Emoticons");
define("ADLAN_59", "Configure emoticons");
define("ADLAN_60", "Front Page");
define("ADLAN_61", "Configure front page content");
//define("ADLAN_62", "News Feeds");
//define("ADLAN_63", "Configure news feeds");
//define("ADLAN_64", "Log Stats");
//define("ADLAN_65", "Log stats/counter etc");
define("ADLAN_66", "Meta Tags");
define("ADLAN_67", "Add/Edit site meta tags");
define("ADLAN_68", "PHP Info");
define("ADLAN_69", "PHP Info page");
//define("ADLAN_70", "Polls");
//define("ADLAN_71", "Add/Edit Polls");
define("ADLAN_72", "Public Uploads");
define("ADLAN_73", "Configure public file uploads");
define("ADLAN_74", "Cache");
define("ADLAN_75", "Set cache status");
//define("ADLAN_77", "You have had a news item submitted - please click here to check.");
define("ADLAN_78", "Extended User Fields");
define("ADLAN_79", "Edit extended user fields");


//define("ADLAN_86", "Incorrect password ");
//define("ADLAN_87", "Administrator name not found in database ");
//define("ADLAN_88", "Unable to login ");
define("ADLAN_89", "Admin Name ");
define("ADLAN_90", "Admin Password ");
define("ADLAN_91", "Log In");
define("ADLAN_92", "Please log in to proceed to administration area ...");
define("ADLAN_93", "Show Admin Functions");
//define("ADLAN_94", "Show Installed Plugins");
define("ADLAN_95", "Plugin Management");
//define("ADLAN_96", "None");
//define("ADLAN_97", "Click here for FAQ");
define("ADLAN_98", "Plugin Manager");
define("ADLAN_99", "Install/upgrade etc. plugins");
//define("ADLAN_100", "Theme Layout");
//define("ADLAN_101", "Template Creator");
define("ADLAN_102", "It has been more than 30 days since you changed the main administrator password - ");
define("ADLAN_103", "Click here to change it now");
define("ADLAN_104", "Security");

define("ADLAN_105", "Images");
define("ADLAN_106", "Image Settings");

//define("ADLAN_107", "Unchecked submitted news items");
//define("ADLAN_108", "Unchecked file uploads");
//define("ADLAN_109", "Information");
define("ADLAN_110", "Registered members");
define("ADLAN_111", "Unverified members");
define("ADLAN_112", "Banned users");
define("ADLAN_113", "Forum posts");
define("ADLAN_114", "Comments");
define("ADLAN_115", "Chatbox posts");
define("ADLAN_116", "Admin log ...");
define("ADLAN_117", "Show all entries");
define("ADLAN_118", "Clear log");

define("ADLAN_119", "Unchecked submitted links");

define("ADLAN_120", "There is a database update available, please click button to install ...");
define("ADLAN_121", "Install");


//define("ADLAN_123", "Unchecked submitted articles");
//define("ADLAN_124", "Unchecked submitted reviews");

//define("ADLAN_125", "Unchecked reported forum posts");

//define("ADLAN_126", "Main Options");
//define("ADLAN_127", "Users");
//define("ADLAN_128", "Content");
//define("ADLAN_129", "Communication");
//define("ADLAN_130", "Files Management");
//define("ADLAN_131", "Other tools");

define("ADLAN_132", "Language");
define("ADLAN_133", "default");

define("ADLAN_134", "Status");
define("ADLAN_135", "Admin Log");

define("ADLAN_136", "Mail");
define("ADLAN_137", "Email Settings And Mailout");

define("ADLAN_138", "Site Links");
define("ADLAN_139", "Add/edit/delete links");

define("ADLAN_140", "Theme Manager");
define("ADLAN_141", "Install / set themes etc");

define("ADLAN_142", "Search");
define("ADLAN_143", "Search Configuration");
define("ADLAN_144", "You are in simple-view mode, to switch to advanced-view");
define("ADLAN_145", "click here");

define("ADLAN_146", "Failed login attempts");
define("ADLAN_147", "File Inspector");
define("ADLAN_148", "Scan site files");

define("ADLAN_149", "Notify");
define("ADLAN_150", "Admin Email Notifications");

define("ADLAN_151", "Main");
define("ADLAN_152", "Enter Code");

define("ADLAN_153", "Administration Area");
define('ADLAN_154', "Error contacting e107.org to check for new version");

define('ADLAN_CL_1', 'Settings');
define('ADLAN_CL_2', 'Users');
define('ADLAN_CL_3', 'Content');
define('ADLAN_CL_4', 'Coms');
define('ADLAN_CL_5', 'Files');
define('ADLAN_CL_6', 'Tools');
define('ADLAN_CL_7', 'Plugins');
define('ADLAN_CL_8', 'Docs');

define("ADLAN_LAT_1", "Latest");

define("ADLAN_LAT_2", "Submitted news items");
//define("ADLAN_LAT_3", "Submitted articles");
//define("ADLAN_LAT_4", "Submitted reviews");
define("ADLAN_LAT_5", "Submitted links");
define("ADLAN_LAT_6", "Reported forum posts");
define("ADLAN_LAT_7", "File uploads");
define("ADLAN_LAT_8", "There are unmoderated administrator messages");

//LAN_WARNING define("ADLAN_ERR_1", "Warning!");
define("ADLAN_ERR_2", "There are files on your server that are known to be exploitable. These must be removed <b>immediately</b>. The files are related to the older 0.6xx branch of e107. Please delete the following directories and all their contents:");
define("ADLAN_ERR_3", "There are one or more files in your public upload directories that are not in your allowed upload filetypes list. These may have been placed here by an attacker and if so should be removed <b>immediately</b>. You should <b>not</b> open these files as this may execute any malicious code the file might contain; e.g. do not open them with your browser.<br /><br />If you recognise these files as being legitimate, it is likely that the filetype is no longer in the allowed filetypes list for some reason, and you will need to re-add it (see admin => uploads). You should not allow the upload of .html, .txt, etc as an attacker may upload a file of this type which includes malicious javascript. You should also, of course, not allow the upload of .php files or any other type of executable script.<br /><br />Below is the list of files that could potentially be malicious:");
define("ADLAN_ERR_4", "Deprecated plugin file(s) found");
define("ADLAN_ERR_5", "The following files need to be renamed to");
define("ADLAN_ERR_6", "Then, click here to re-scan your plugin folders.");


// Common Terms
define("LAN_EDIT","Edit");
define("LAN_DELETE","Delete");
define("LAN_CREATE","Create");
define("LAN_UPDATE","Update");
define("LAN_SAVE","Save");
define("LAN_SAVED","Saved");
define("LAN_SETSAVED","Your settings have been saved");
define("LAN_CONFIRMDEL","Please confirm you wish to delete");
define("LAN_OPTIONS","Options");
define("LAN_PREFS","Preferences");
define("LAN_DELETED","Successfully deleted");
define("LAN_UPDATED","Successfully updated");
define("LAN_CREATED","Successfully created");
define("LAN_CREATED_FAILED","Creation Unsuccessful");
define("LAN_DELETED_FAILED","Deletion Unsuccessful");
define("LAN_UPDATED_FAILED","Update Unsuccessful");
define("LAN_NO_CHANGE","Update unsuccessful as no changes were made.");
define("LAN_TRY_AGAIN","Please try again.");

define("LAN_RESET","Reset");
define("LAN_CLEAR","Clear");
define("LAN_OK","OK");

define("LAN_PRESET","Preset");
define("LAN_PRESET_SAVED","Preset saved successfully");

define("LAN_PRESET_DELETED","Preset successfully deleted");
define("LAN_PRESET_CONFIRMDEL","Are you sure you want to delete this preset?");
define("LAN_NOTWRITABLE"," is not writable, you need to CHMOD 777 the file or folder first.");
define("LAN_DATE","Date");
define("LAN_TIME","Time");
define("LAN_YES","Yes");
define("LAN_NO","No");
define("LAN_EMPTY","There are no entries in the database yet");
define("LAN_EXISTING","Existing Entries");

define("LAN_CANCEL","Cancel");
define("LAN_CONFDELETE","Confirm Delete");
define("LAN_PLUGIN","Plugin");
define("LAN_ORDER","Order");

define("LAN_SELECT","Select ...");
define("LAN_ADMIN","Admin");
define("LAN_DISPLAYOPT", "Edit Display Options");
define("LAN_GOPAGE", "Go to page:");
define("LAN_DATESTAMP","Date stamp");
define("LAN_OPTIONAL", "optional");
define("LAN_INACTIVE","Inactive");

define("LAN_BAN","Ban");
define("LAN_RATING", "Rating");

define("LAN_UPLOAD", "Upload");
define("LAN_UPLOAD_IMAGES","Upload Images");
define("LAN_UPLOAD_FILES","Upload Files");
define("LAN_UPLOAD_ADDFILE","Add Another File");
define("LAN_UPLOAD_CONFIRM","Any unsaved changes to this page will be lost. Continue?");
define("LAN_UPLOAD_777","Folder is missing or not writable, you need to CHMOD 777 the following folder before uploading:");
define("LAN_UPLOAD_SERVEROFF", "This option is disabled as file uploading is not enabled on your server");

define("LAN_DISABLED","Disabled");
define("LAN_ENABLED", "Enabled");

define("LAN_PRESET_CONFIRMSAVE","Save current form values as the default for this page?");
define("LAN_CONFIGURE", "Configure");

define("LAN_BACK","Back");

define("LAN_CREDITS","Credits");
define("LAN_NEWVERSION","New Version Available");
define("LAN_NEWVERSION_MORE","learn more");
define("LAN_NEWVERSION_DLD","Download %s from SF.net");
?>

==> e107-1.0.0.tbz: www/e107/e107_languages/English/admin/lan_admin.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_admin.php $
|     $Revision: 12315 $
|     $Id: lan_admin.php 12315 2011-07-08 03:02:34Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("ADLAN_0", "News");
define("ADLAN_1", "Add/edit/delete news items");
//define("ADLAN_2", "News Categories");
//define("ADLAN_3", "Add/edit/delete news categories");
define("ADLAN_4", "Preferences");
define("ADLAN_5", "Edit Site Preferences");
define("ADLAN_6", "Menus");
define("ADLAN_7", "Alter the order of your menus");
define("ADLAN_8", "Administrators");
define("ADLAN_9", "Add/delete site administrators");
define("ADLAN_10", "Admin password");
define("ADLAN_11", "Change your password");
//define("ADLAN_12", "Forums");
//define("ADLAN_13", "Add/Edit Forums");
//define("ADLAN_14", "Articles");
//define("ADLAN_15", "Add new/edit/delete articles");
//define("ADLAN_16", "Content");
//define("ADLAN_17", "Add new/edit/delete content pages");
//define("ADLAN_18", "Reviews");
//define("ADLAN_19", "Add new/edit/delete reviews");
//define("ADLAN_22", "Link Categories");
//define("ADLAN_23", "Add new/edit/delete link categories");
define("ADLAN_24", "Downloads");
define("ADLAN_25", "Manage Downloads");
//define("ADLAN_26", "Download Categories");
//define("ADLAN_27", "Add new/edit/delete download categories");
define("ADLAN_28", "Welcome Message");
define("ADLAN_29", "Set static welcome message");
define("ADLAN_30", "File Manager");
define("ADLAN_31", "Manage/upload files");
//define("ADLAN_32", "Submitted News");
//define("ADLAN_33", "Review user submitted news items");
define("ADLAN_34", "Banlist");
define("ADLAN_35", "Ban visitors");
define("ADLAN_36", "Users");
define("ADLAN_37", "Moderate site members");
define("ADLAN_38", "User Classes");
define("ADLAN_39", "Create/edit user classes");
define("ADLAN_40", "Maintenance");
define("ADLAN_41", "Take site down for maintenance");
define("ADLAN_42", "Custom Menus/Pages");
define("ADLAN_43", "Create custom menu items");
define("ADLAN_44", "Database");
define("ADLAN_45", "Database utilities");
define("ADLAN_46", "Logout");
define("ADLAN_47", "Welcome");
define("ADLAN_48", "Logged in");
define("ADLAN_49", "main site administrator");
//define("ADLAN_50", "permissions");
define("ADLAN_51", "Please log in to gain access to administration area");
define("ADLAN_52", "Admin Front Page");
define("ADLAN_53", "Leave Admin");
define("ADLAN_54", "Banners");
define("ADLAN_55", "Configure banners");
//define("ADLAN_56", "Chatbox");
//define("ADLAN_57", "Configure chatbox");
define("ADLAN_58", "Emoticons");
define("ADLAN_59", "Configure emoticons");
define("ADLAN_60", "Front Page");
define("ADLAN_61", "Configure front page content");
//define("ADLAN_62", "News Feeds");
//define("ADLAN_63", "Configure news feeds");
//define("ADLAN_64", "Log Stats");
//define("ADLAN_65", "Log stats/counter etc");
define("ADLAN_66", "Meta Tags");
define("ADLAN_67", "Add/Edit site meta tags");
define("ADLAN_68", "PHP Info");
define("ADLAN_69", "PHP Info page");
//define("ADLAN_70", "Polls");
//define("ADLAN_71", "Add/Edit Polls");
define("ADLAN_72", "Public Uploads");
define("ADLAN_73", "Configure public file uploads");
define("ADLAN_74", "Cache");
define("ADLAN_75", "Set cache status");
//define("ADLAN_77", "You have had a news item submitted - please click here to check.");
define("ADLAN_78", "Extended User Fields");
define("ADLAN_79", "Edit extended user fields");


//define("ADLAN_86", "Incorrect password ");
//define("ADLAN_87", "Administrator name not found in database ");
//define("ADLAN_88", "Unable to login ");
define("ADLAN_89", "Admin Name ");
define("ADLAN_90", "Admin Password ");
define("ADLAN_91", "Log In");
define("ADLAN_92", "Please log in to proceed to administration area ...");
define("ADLAN_93", "Show Admin Functions");
//define("ADLAN_94", "Show Installed Plugins");
define("ADLAN_95", "Plugin Management");
//define("ADLAN_96", "None");
//define("ADLAN_97", "Click here for FAQ");
define("ADLAN_98", "Plugin Manager");
define("ADLAN_99", "Install/upgrade etc. plugins");
//define("ADLAN_100", "Theme Layout");
//define("ADLAN_101", "Template Creator");
define("ADLAN_102", "It has been more than 30 days since you changed the main administrator password - ");
define("ADLAN_103", "Click here to change it now");
define("ADLAN_104", "Security");

define("ADLAN_105", "Images");
define("ADLAN_106", "Image Settings");

//define("ADLAN_107", "Unchecked submitted news items");
//define("ADLAN_108", "Unchecked file uploads");
//define("ADLAN_109", "Information");
define("ADLAN_110", "Registered members");
define("ADLAN_111", "Unverified members");
define("ADLAN_112", "Banned users");
define("ADLAN_113", "Forum posts");
define("ADLAN_114", "Comments");
define("ADLAN_115", "Chatbox posts");
define("ADLAN_116", "Admin log ...");
define("ADLAN_117", "Show all entries");
define("ADLAN_118", "Clear log");

define("ADLAN_119", "Unchecked submitted links");

define("ADLAN_120", "There is a database update available, please click button to install ...");
define("ADLAN_121", "Install");


//define("ADLAN_123", "Unchecked submitted articles");
//define("ADLAN_124", "Unchecked submitted reviews");

//define("ADLAN_125", "Unchecked reported forum posts");

//define("ADLAN_126", "Main Options");
//define("ADLAN_127", "Users");
//define("ADLAN_128", "Content");
//define("ADLAN_129", "Communication");
//define("ADLAN_130", "Files Management");
//define("ADLAN_131", "Other tools");

define("ADLAN_132", "Language");
define("ADLAN_133", "default");

define("ADLAN_134", "Status");
define("ADLAN_135", "Admin Log");

define("ADLAN_136", "Mail");
define("ADLAN_137", "Email Settings And Mailout");

define("ADLAN_138", "Site Links");
define("ADLAN_139", "Add/edit/delete links");

define("ADLAN_140", "Theme Manager");
define("ADLAN_141", "Install / set themes etc");

define("ADLAN_142", "Search");
define("ADLAN_143", "Search Configuration");
define("ADLAN_144", "You are in simple-view mode, to switch to advanced-view");
define("ADLAN_145", "click here");

define("ADLAN_146", "Failed login attempts");
define("ADLAN_147", "File Inspector");
define("ADLAN_148", "Scan site files");

define("ADLAN_149", "Notify");
define("ADLAN_150", "Admin Email Notifications");

define("ADLAN_151", "Main");
define("ADLAN_152", "Enter Code");

define("ADLAN_153", "Administration Area");
define('ADLAN_154', "Error contacting e107.org to check for new version");

define('ADLAN_CL_1', 'Settings');
define('ADLAN_CL_2', 'Users');
define('ADLAN_CL_3', 'Content');
define('ADLAN_CL_4', 'Coms');
define('ADLAN_CL_5', 'Files');
define('ADLAN_CL_6', 'Tools');
define('ADLAN_CL_7', 'Plugins');
define('ADLAN_CL_8', 'Docs');

define("ADLAN_LAT_1", "Latest");

define("ADLAN_LAT_2", "Submitted news items");
//define("ADLAN_LAT_3", "Submitted articles");
//define("ADLAN_LAT_4", "Submitted reviews");
define("ADLAN_LAT_5", "Submitted links");
define("ADLAN_LAT_6", "Reported forum posts");
define("ADLAN_LAT_7", "File uploads");
define("ADLAN_LAT_8", "There are unmoderated administrator messages");

//LAN_WARNING define("ADLAN_ERR_1", "Warning!");
define("ADLAN_ERR_2", "There are files on your server that are known to be exploitable. These must be removed <b>immediately</b>. The files are related to the older 0.6xx branch of e107. Please delete the following directories and all their contents:");
define("ADLAN_ERR_3", "There are one or more files in your public upload directories that are not in your allowed upload filetypes list. These may have been placed here by an attacker and if so should be removed <b>immediately</b>. You should <b>not</b> open these files as this may execute any malicious code the file might contain; e.g. do not open them with your browser.<br /><br />If you recognise these files as being legitimate, it is likely that the filetype is no longer in the allowed filetypes list for some reason, and you will need to re-add it (see admin => uploads). You should not allow the upload of .html, .txt, etc as an attacker may upload a file of this type which includes malicious javascript. You should also, of course, not allow the upload of .php files or any other type of executable script.<br /><br />Below is the list of files that could potentially be malicious:");
define("ADLAN_ERR_4", "Deprecated plugin file(s) found");
define("ADLAN_ERR_5", "The following files need to be renamed to");
define("ADLAN_ERR_6", "Then, click here to re-scan your plugin folders.");
define("ADLAN_ERR_7", "Malicious files have been detected on your server. They should be deleted [b]immediately[/b].");
define("ADLAN_ERR_8", "Please run [File inspector] to check for core files that may have been modified.");

// Common Terms
define("LAN_EDIT","Edit");
define("LAN_DELETE","Delete");
define("LAN_CREATE","Create");
define("LAN_UPDATE","Update");
define("LAN_SAVE","Save");
define("LAN_SAVED","Saved");
define("LAN_SETSAVED","Your settings have been saved");
define("LAN_CONFIRMDEL","Please confirm you wish to delete");
define("LAN_OPTIONS","Options");
define("LAN_PREFS","Preferences");
define("LAN_DELETED","Successfully deleted");
define("LAN_UPDATED","Successfully updated");
define("LAN_CREATED","Successfully created");
define("LAN_CREATED_FAILED","Creation Unsuccessful");
define("LAN_DELETED_FAILED","Deletion Unsuccessful");
define("LAN_UPDATED_FAILED","Update Unsuccessful");
define("LAN_NO_CHANGE","Update unsuccessful as no changes were made.");
define("LAN_TRY_AGAIN","Please try again.");

define("LAN_RESET","Reset");
define("LAN_CLEAR","Clear");
define("LAN_OK","OK");

define("LAN_PRESET","Preset");
define("LAN_PRESET_SAVED","Preset saved successfully");

define("LAN_PRESET_DELETED","Preset successfully deleted");
define("LAN_PRESET_CONFIRMDEL","Are you sure you want to delete this preset?");
define("LAN_NOTWRITABLE"," is not writable, you need to CHMOD 777 the file or folder first.");
define("LAN_DATE","Date");
define("LAN_TIME","Time");
define("LAN_YES","Yes");
define("LAN_NO","No");
define("LAN_EMPTY","There are no entries in the database yet");
define("LAN_EXISTING","Existing Entries");

define("LAN_CANCEL","Cancel");
define("LAN_CONFDELETE","Confirm Delete");
define("LAN_PLUGIN","Plugin");
define("LAN_ORDER","Order");

define("LAN_SELECT","Select ...");
define("LAN_ADMIN","Admin");
define("LAN_DISPLAYOPT", "Edit Display Options");
define("LAN_GOPAGE", "Go to page:");
define("LAN_DATESTAMP","Date stamp");
define("LAN_OPTIONAL", "optional");
define("LAN_INACTIVE","Inactive");

define("LAN_BAN","Ban");
define("LAN_RATING", "Rating");

define("LAN_UPLOAD", "Upload");
define("LAN_UPLOAD_IMAGES","Upload Images");
define("LAN_UPLOAD_FILES","Upload Files");
define("LAN_UPLOAD_ADDFILE","Add Another File");
define("LAN_UPLOAD_CONFIRM","Any unsaved changes to this page will be lost. Continue?");
define("LAN_UPLOAD_777","Folder is missing or not writable, you need to CHMOD 777 the following folder before uploading:");
define("LAN_UPLOAD_SERVEROFF", "This option is disabled as file uploading is not enabled on your server");

define("LAN_DISABLED","Disabled");
define("LAN_ENABLED", "Enabled");

define("LAN_PRESET_CONFIRMSAVE","Save current form values as the default for this page?");
define("LAN_CONFIGURE", "Configure");

define("LAN_BACK","Back");

define("LAN_CREDITS","Credits");
define("LAN_NEWVERSION","New Version Available");
define("LAN_NEWVERSION_MORE","learn more");
define("LAN_NEWVERSION_DLD","Download %s from SF.net");
define('LAN_NEWVERSION_CHECK_ERROR', 'Version check error');

define("LAN_SECURITYL_0", "Looking for troubles (none)");
define("LAN_SECURITYL_5", "Balanced");
define("LAN_SECURITYL_8", "High");
define("LAN_SECURITYL_10", "Insane");
?>
